.. SymPy documentation master file, created by sphinx-quickstart.py on Sat Mar 22 19:34:32 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to SymPy's documentation!
=================================

A PDF version of these docs can be found `here <https://github.com/sympy/sympy/releases>`_.

`SymPy <http://sympy.org>`_ is a Python library for symbolic mathematics.
If you are new to SymPy, start with the :ref:`Tutorial <tutorial>`.

This is the central page for all of SymPy's documentation.


Contents:

.. toctree::
   :maxdepth: 2

   install.rst
   tutorial/index.rst
   gotchas.rst
   guide.rst
   modules/index.rst
   special_topics/index.rst
   python-comparisons.rst
   wiki.rst
   outreach.rst
   aboutus.rst
   citing.rst
